pub struct SettingInfo {
id: String,
name: String,
min: Option<String>,
max: Option<String>,
step: Option<String>,
unit: Option<String>,
values: Option<Vec<SettingInfo>>,
}Expand description
A struct representing a piece of SettingInfo
Fields
id: Stringname: Stringmin: Option<String>max: Option<String>step: Option<String>unit: Option<String>values: Option<Vec<SettingInfo>>Implementations
Sourceimpl SettingInfo
Generate setting info. This should probably be changed to be done at compile time.
impl SettingInfo
Generate setting info. This should probably be changed to be done at compile time.
pub fn get_archiver_settings() -> Vec<SettingInfo>
pub fn get_server_settings() -> Vec<SettingInfo>