Hdf5Object

Trait Hdf5Object 

pub trait Hdf5Object {
    // Required methods
    fn to_hdf5(&self, file: &mut File) -> Result<()>;
    fn from_hdf5(idx: usize, file: &File) -> Result<Self>
       where Self: Sized;
}
An Hdf5Object can be stored and retrieved from an HDF5 file.

Required Methods

fn to_hdf5(&self, file: &mut File) -> Result<()>

Stores the object in the specified file.

fn from_hdf5(idx: usize, file: &File) -> Result<Self>
where Self: Sized,

Retrieves an object from the specified file and index.

Implementors

Source

impl Hdf5Object for ComPacket

Implementation of HDF5Object for ComPacket.